/**
 * A proxy (or called accessor) of the ProcessContext, to provide a grace interface to use
 */
import { ProcessContext } from './ProcessContext';
import { Environment } from 'pandora-env';
import { Service } from '../domain';
import { Facade as HubFacade } from 'pandora-hub';
import { DefaultObjectProxy, ObjectDescription, ConsumerExtInfo } from 'pandora-hub';
/**
 * Class ProcessContextAccessor
 * A easy way to access ProcessContext
 */
export declare class ProcessContextAccessor {
    /**
     * Original context object
     */
    context: ProcessContext;
    /**
     * @param context - Original context object
     */
    constructor(context: any);
    /**
     * Current application name
     * @returns {string}
     */
    readonly appName: string;
    /**
     * Current application directory path
     * @returns {string}
     */
    readonly appDir: string;
    /**
     * Current process name, such as worker, background
     * @returns {string}
     */
    readonly processName: string;
    /**
     * Current environment identical string, such as production, development
     * @returns {string}
     */
    readonly env: string;
    /**
     * Environment object, that should injected by procfile.js or globalConfig
     * @returns {Environment}
     */
    readonly environment: Environment;
    /**
     * Get service instance by service's name
     * @param {string} name - Name of service
     * @returns {Service}
     */
    getService<T extends Service>(name: string): T;
    /**
     * Get a service class by service's name
     * @param {string} name - Name of service
     * @returns {class}
     */
    getServiceClass(name: string): any;
    getHub(): HubFacade;
    getProxy<T extends any>(name: string, extInfo?: ConsumerExtInfo): Promise<T & DefaultObjectProxy>;
    getProxy<T extends any>(objectDescription: ObjectDescription, extInfo?: ConsumerExtInfo): Promise<T & DefaultObjectProxy>;
    publishObject(name: string, obj: any): Promise<void>;
    publishObject(objectDescription: ObjectDescription, obj: any): Promise<void>;
}
