'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const Daemon_1 = require("./Daemon");
const pandora_env_1 = require("pandora-env");
const const_1 = require("../const");
const pandora_metrics_1 = require("pandora-metrics");
const GlobalConfigProcessor_1 = require("../universal/GlobalConfigProcessor");
const LoggerBroker_1 = require("../universal/LoggerBroker");
const pandora_metrics_2 = require("pandora-metrics");
const pandora_hub_1 = require("pandora-hub");
/**
 * Class DaemonBootstrap
 */
class DaemonBootstrap {
    constructor() {
        this.daemonLogger = LoggerBroker_1.getDaemonLogger();
        this.globalConfigProcessor = GlobalConfigProcessor_1.GlobalConfigProcessor.getInstance();
        this.globalConfig = this.globalConfigProcessor.getAllProperties();
    }
    /**
     * Start the daemon
     * @return {Promise<void>}
     */
    async start() {
        try {
            const Environment = this.globalConfig.environment || pandora_env_1.DefaultEnvironment;
            // Register a default env for daemon process
            const daemonEnvironment = new Environment({
                processName: 'daemon',
                appName: pandora_metrics_1.MetricsConstants.METRICS_DEFAULT_APP,
                pandoraLogsDir: LoggerBroker_1.getPandoraLogsDir()
            });
            daemonEnvironment.set(const_1.PANDORA_GLOBAL_CONFIG, this.globalConfig);
            pandora_env_1.EnvironmentUtil.getInstance().setCurrentEnvironment(daemonEnvironment);
            this.ipcHubServer = new pandora_hub_1.Hub();
            await this.ipcHubServer.start();
            this.ipcHub = new pandora_hub_1.Facade();
            this.ipcHub.setup({
                location: {
                    appName: '__pandora_daemon',
                    processName: '__pandora_daemon',
                    pid: process.pid.toString()
                },
                logger: this.daemonLogger
            });
            await this.ipcHub.start();
            pandora_metrics_2.MetricsInjectionBridge.setIPCHub(this.ipcHub);
            this.daemon = new Daemon_1.Daemon();
            await this.daemon.start();
            pandora_metrics_2.MetricsInjectionBridge.setDaemon(this.daemon);
            if (process.send) {
                process.send(const_1.DAEMON_READY);
            }
        }
        catch (err) {
            this.daemonLogger.error(err);
            throw err;
        }
    }
    /**
     * Stop the Daemon
     * @return {Promise<void>}
     */
    async stop() {
        await this.daemon.stop();
        await this.ipcHub.stop();
        await this.ipcHubServer.stop();
    }
}
exports.DaemonBootstrap = DaemonBootstrap;
function cmd() {
    const daemonBootstrap = new DaemonBootstrap;
    return daemonBootstrap.start().catch(() => {
        process.exit(1);
    });
}
exports.cmd = cmd;
if (require.main === module) {
    cmd();
}
//# sourceMappingURL=DaemonBootstrap.js.map